@@ -15,6 +15,7 @@
 #' @param force.redo If an extraction for this template and label already exists, should a new one be created?
 #' @return A \code{RasterLayer} DEM cropped to the extent of the template.
 #' @export
+#' @importFrom magrittr %>%
 #' @examples
 #' \dontrun{
 #' # Extract data for the Village Ecodynamics Project "VEPIIN" study area:
@@ -52,9 +53,11 @@ get_ned <- function(template, label, res="1", raw.dir="./RAW/NED/", extraction.d
   message("Area of interest includes ",nrow(tilesLocations)," NED tiles.")
   
   # Download and crop tiles
-  tiles <- apply(tilesLocations,1,function(loc){
-    return(get_ned_tile(template=template, res=res, tileNorthing=loc[1], tileWesting=loc[2], raw.dir=raw.dir))
+  tiles <- apply(tilesLocations, 1, function(loc) {
+    return(tryCatch(get_ned_tile(template = template, res = res, tileNorthing = loc[1], 
+                                 tileWesting = loc[2], raw.dir = raw.dir), error=function(e) NULL))
   })
+  tiles <- tiles[which(!unlist(lapply(tiles, is.null)))]
   
   # Mosaic all tiles
   if(length(tiles)>1){
@@ -69,9 +72,27 @@ get_ned <- function(template, label, res="1", raw.dir="./RAW/NED/", extraction.d
     tiles <- tiles[[1]]
   }
   
-  tiles <- raster::crop(tiles,sp::spTransform(template,sp::CRS(raster::projection(tiles))), snap="out")
-  
-  raster::writeRaster(tiles, paste(extraction.dir,"/",label,"_NED_",res,".tif", sep=''), datatype="FLT4S", options=c("COMPRESS=DEFLATE", "ZLEVEL=9", "INTERLEAVE=BAND"), overwrite=T, setStatistics=FALSE)
+  tiles <- tryCatch(tiles %>%
+                      raster::crop(y = template %>%
+                                     sp::spTransform(CRSobj = tiles %>%
+                                                       raster::projection()
+                                                     )
+                                   ,
+                                   snap = "out"),
+                    error = function(e){
+                      tiles %>%
+                        raster::crop(y = template %>%
+                                       sp::spTransform(CRSobj = tiles %>%
+                                                         raster::projection()
+                                       )
+                                     )
+                    })
+
+  raster::writeRaster(tiles,
+                      paste(extraction.dir,"/",label,"_NED_",res,".tif", sep=''),
+                      datatype="FLT4S", options=c("COMPRESS=DEFLATE", "ZLEVEL=9", "INTERLEAVE=BAND"),
+                      overwrite=T,
+                      setStatistics=FALSE)
   
   return(tiles)
 }
@@ -125,6 +146,7 @@ download_ned_tile <- function(res="1", tileNorthing, tileWesting, raw.dir){
 #' The directory will be created if missing. Defaults to "./RAW/NED/".
 #' @return A \code{RasterLayer} cropped within the specified \code{template}.
 #' @export
+#' @importFrom magrittr %>%
 #' @keywords internal
 get_ned_tile <- function(template=NULL, res="1", tileNorthing, tileWesting, raw.dir){
   tmpdir <- tempfile()
@@ -143,7 +165,21 @@ get_ned_tile <- function(template=NULL, res="1", tileNorthing, tileWesting, raw.
   tile <- raster::raster(dirs)
   
   if(!is.null(template)){
-    tile <- tryCatch(raster::crop(tile,sp::spTransform(template,sp::CRS(raster::projection(tile))), snap="out"), error=function(e){raster::crop(tile,sp::spTransform(template,sp::CRS(raster::projection(tile))))})
+    tile <- tryCatch(tile %>%
+                        raster::crop(y = template %>%
+                                       sp::spTransform(CRSobj = tile %>%
+                                                         raster::projection()
+                                       )
+                                     ,
+                                     snap = "out"),
+                      error = function(e){
+                        tile %>%
+                          raster::crop(y = template %>%
+                                         sp::spTransform(CRSobj = tile %>%
+                                                           raster::projection()
+                                         )
+                          )
+                      })
   }
   
   tile <- tile*1
